@@ -25,20 +25,3 @@ test_that("`detect()` requires a predicate function", {
   expect_snapshot(detect(list(1:2, 2), is.na), error = TRUE)
   expect_snapshot(detect_index(list(1:2, 2), is.na), error = TRUE)
 })
-
-
-# Lifecycle ---------------------------------------------------------------
-
-test_that("`.right` argument is retired", {
-  expect_snapshot({
-    . <- detect(1:2, ~TRUE, .right = TRUE)
-    . <- detect_index(1:2, ~TRUE, .right = TRUE)
-  })
-})
-
-test_that("`.right` argument still works", {
-  local_options(lifecycle_verbosity = "quiet")
-  is_odd <- function(x) x %% 2 == 1
-  expect_equal(detect(y, is_odd, .right = TRUE), 9)
-  expect_equal(detect_index(y, is_odd, .right = TRUE), 6)
-})
